summaryrefslogtreecommitdiffstats
path: root/ctok_token.c
diff options
context:
space:
mode:
Diffstat (limited to 'ctok_token.c')
-rw-r--r--ctok_token.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ctok_token.c b/ctok_token.c
index a0f6b18d..11667323 100644
--- a/ctok_token.c
+++ b/ctok_token.c
@@ -61,13 +61,13 @@ CODESTARTobjDestruct(ctok_token)
ENDobjDestruct(ctok_token)
/* get the rsCStrObj from the token, but do not destruct it. This is meant to
* be used by a caller who passes on the string to some other function. The
* caller is responsible for destructing it.
* rgerhards, 2008-02-20
*/
rsRetVal
-ctok_tokenUnlinkCStr(ctok_token_t *pThis, rsCStrObj **ppCStr)
+ctok_tokenUnlinkCStr(ctok_token_t *pThis, cstr_t **ppCStr)
{
DEFiRet;
@@ -61,13 +61,13 @@ CODESTARTobjDestruct(ctok_token)
ENDobjDestruct(ctok_token)
-/* get the rsCStrObj from the token, but do not destruct it. This is meant to
+/* get the cstr_t from the token, but do not destruct it. This is meant to
* be used by a caller who passes on the string to some other function. The
* caller is responsible for destructing it.